@@ -435,7 +435,7 @@ int khttp_connect_file(knetFile *fp)
 	fp->fd = socket_connect(fp->host, fp->port);
 	buf = calloc(0x10000, 1); /* FIXME: I am lazy... But in principle, 64KB should be large enough. */
 	l += sprintf(buf + l, "GET %s HTTP/1.0\r\nHost: %s\r\n", fp->path, fp->http_host);
-    l += sprintf(buf + l, "Range: bytes=%" PRIu64 "-\r\n", fp->offset);
+    l += sprintf(buf + l, "Range: bytes=%" PRId64 "-\r\n", fp->offset);
 	l += sprintf(buf + l, "\r\n");
 	byteswritten = netwrite(fp->fd, buf, l);	/* @ubw fixed unused result warning */
 	if( 0 >= byteswritten )			/* do sth with the result */
